package com.lilosoft.core.exception;

import com.lilosoft.core.model.JsonResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.annotation.Order;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * 全局的的异常拦截器（拦截所有的控制器）（带有@RequestMapping注解的方法上都会拦截）
 *
 * @author YanJie
 */
@ControllerAdvice
@Order(-1)
public class GlobalExceptionHandler {

    private Logger log = LoggerFactory.getLogger(this.getClass());

    /**
     * token验证请求参数异常
     */
    @ExceptionHandler(IllegalArgumentException.class)
    @ResponseBody
    public JsonResult illegalArgumentExceptionHandler(IllegalArgumentException exception) {
        return JsonResult.returnException(exception);
    }


    /**
	 * 全局异常拦截，封装报错信息
	 * 
	 * @param exception
	 * @return
	 */
	@ExceptionHandler(Exception.class)
	@ResponseBody
	public JsonResult runtimeExceptionHandler(Exception exception) {
		log.error("运行时操作异常:", exception);
		return JsonResult.returnException(exception);
	}
}
