package com.lilosoft.core.executor;

import com.lilosoft.core.executor.handler.Handler;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

/** 
 * @ClassName: NonOrderedQueuePoolExecutor 
 * @Description: 无序队列线程池
 * @author: QiuSheng
 * @date: 创建时间：2017年12月7日 下午4:07:33 
 */
public class NonOrderedQueuePoolExecutor extends ThreadPoolExecutor {
	
	/**
	 * 日志对象
	 */
	protected Logger logger = LoggerFactory.getLogger(getClass());
	
	public NonOrderedQueuePoolExecutor(int corePoolSize) {
		super(corePoolSize, corePoolSize, 30, TimeUnit.SECONDS, new LinkedBlockingQueue<Runnable>());
	}

	public void execute(Handler command) {
		Work work = new Work(command);
		execute(work);
	}

	private class Work implements Runnable {

		private Handler command;

		public Work(Handler command) {
			this.command = command;
		}

		public void run() {
			long start = System.currentTimeMillis();
			try {
				command.action();
			} catch (Exception e) {
				logger.error("command.getClass().getSimpleName() Exception", e);
			} finally {
				long end = System.currentTimeMillis();
				if (end - start > 50) {
					logger.error("NonOrderedQueuePoolExecutor-->" + command.getClass().getSimpleName() + " run:"
							+ (end - start));
				}
			}

		}
	}
}
